@@ -56,6 +56,7 @@ class Geo_common:
                 if len(tmp) == 1 :
                     self.samples[line[0]][head] = tmp
                 else:
+                    self.samples[line[0]][head] = []
                     for i in tmp:
                         if not i: continue                             # 防止出现空值
                         self.samples[line[0]][head].append(i)
@@ -175,7 +176,7 @@ cd %s
 
 %s/script/DataRelease.py --yaml %s --odir %s/Upload/ && \\
 
-python3 -m excelParse.upload -i %s/Uplaod/ -o %s 
+python3 -m excelParse.upload -i %s/Upload/ -o %s 
 
 if [ $? -eq 0 ];
 then
